@@ -80,9 +80,10 @@ class Strategy(object):
         open_times = Environment.get_instance().basicdata_api.GetOpenTimes(begin,end)
         if open_times is None or len(open_times) <= 0:
             return
-        raise_time = event.raise_time + datetime.timedelta(hours=13)
+        night_time = event.raise_time + datetime.timedelta(hours=1)
+        day_time = event.raise_time + datetime.timedelta(hours=13)
         for x in open_times:
-            if raise_time >= datetime.datetime.strptime(x.begin,'%Y%m%d%H%M%S') and raise_time <= datetime.datetime.strptime(x.end,'%Y%m%d%H%M%S'):
+            if (night_time >= datetime.datetime.strptime(x.begin,'%Y%m%d%H%M%S') and night_time <= datetime.datetime.strptime(x.end,'%Y%m%d%H%M%S')) or (day_time >= datetime.datetime.strptime(x.begin,'%Y%m%d%H%M%S') and day_time <= datetime.datetime.strptime(x.end,'%Y%m%d%H%M%S')) :
                 logger.info("begin on_open")
                 self.__handle_open(self.__user_context)
                 logger.info("on_open complated")
