@@ -32,32 +32,32 @@ class Environment(object):
 
     def get_apiurl(self,relativeUrl):
         if self.config.runtime == 'DEBUG':
-            return urljoin("https://dev_apigateway.inquantstudio.com/", relativeUrl)
+            return urljoin("https://dev-apigateway.inquantstudio.com/", relativeUrl)
         return urljoin("https://apigateway.inquantstudio.com/", relativeUrl)
 
     def get_ykapiurl(self,relativeUrl):
         if self.config.runtime == 'DEBUG':
-            return urljoin("https://dev_vir.inquant.cn/", relativeUrl)
+            return urljoin("https://dev-vir.inquant.cn/", relativeUrl)
         return urljoin("https://vir.inquant.cn/", relativeUrl)
 
     def get_quoteaddr(self):
         if self.config.runtime == 'DEBUG':
-            return "wss://dev_quotegateway.inquantstudio.com"
+            return "wss://dev-quotegateway.inquantstudio.com"
         return "wss://quotegateway.inquantstudio.com"
     
     def get_trademsgaddr(self):
         if self.config.runtime == 'DEBUG':
-            return "wss://dev_apigateway.inquantstudio.com/msg/"
+            return "wss://dev-apigateway.inquantstudio.com/msg/"
         return "wss://apigateway.inquantstudio.com/msg/"
 
     def get_yktrademsgaddr(self):
         if self.config.runtime == 'DEBUG':
-            return "wss://dev_vir.inquant.cn/msg/"
+            return "wss://dev-vir.inquant.cn/msg/"
         return "wss://vir.inquant.cn/msg/"
 
     def get_livetradeaddr(self):
         if self.config.runtime == 'DEBUG':
-            return "https://dev_trade.inquant.cn/tradeAcc/"
+            return "https://dev-trade.inquant.cn/tradeAcc/"
         return "https://trade.inquant.cn/tradeAcc/"
 
 class GlobalConfig(object):
