@@ -32,7 +32,15 @@ def on_init(ctx):
 
     id = ctx.get_strategy_id()
 
-    ctx.subscribe(('cu2010.SHFE','1m'),('rr2009.DCE','1m'),('rb2010.SHFE','1m'),('sc2009.INE','1m'))
+    ctx.subscribe(('cu2106.SHFE','1m'),('rb2110.SHFE','1m'),('fu2109.SHFE','1m'),('ss2106.SHFE','1m'))
+
+    ctx.subscribe(('IH2105.CFFEX','1m'),('IC2105.CFFEX','1m'))
+
+    ctx.subscribe(('m2109.DCE','1m'),('p2109.DCE','1m'))
+
+    ctx.subscribe(('AP109.CZCE','1m'),('CJ109.CZCE','1m'))
+
+    ctx.subscribe(('bc2106.INE','1m'),('sc2106.INE','1m'))
 
     ctx.domi_contract = ctx.get_dominant_contract(ctx.symbol)
     conInfo = ctx.get_contract(ctx.domi_contract.symbol)
@@ -101,8 +109,8 @@ def on_bar(ctx,bar):
     logger.info('bar:{0},{1},{2}'.format(bar.symbol,bar.local_time,bar.close))
     
 config = {
-    "runtime":"DEBUG",
-    "run_type":"LIVE_TRADING",
+    "runtime":"RELEASE",
+    #"run_type":"LIVE_TRADING",
     "log":{
             'level':'INFO',
             'file' :"/home/sunliusi/logs/strategy.log",
