@@ -308,9 +308,9 @@ if __name__ == '__main__':
 
     event_bus = EventBus()
 
-    event_bus.add_listener(EVENT.On_Bar,lambda msg:logger.info('bar:{0},{1},{2}'.format(msg.data.Symbol,msg.data.LocalTime,msg.data.ClosePx)))
+    event_bus.add_listener(EVENT.On_Bar,lambda msg:logger.info('bar:{0},{1},{2}'.format(msg.data.symbol,msg.data.local_time,msg.data.close)))
 
-    event_bus.add_listener(EVENT.On_Tick,lambda msg:logger.info('tick:{0},{1},{2}'.format(msg.data.Symbol,msg.data.LocalTime,msg.data.LastPx)))
+    event_bus.add_listener(EVENT.On_Tick,lambda msg:logger.info('tick:{0},{1},{2}'.format(msg.data.symbol,msg.data.local_time,msg.data.pre_close)))
 
     api = MarketApi(event_bus)
     api.Init()
@@ -320,7 +320,7 @@ if __name__ == '__main__':
 
     event_bus.start()
 
-    ret1 = api.Subscribe("rb2010.SHFE.TICK.0","rb2010.SHFE.BAR.300","rb2005.SHFE.TICK.0")
+    ret1 = api.Subscribe("rb2010.SHFE.TICK.0","rb2010.SHFE.BAR.60","rb2005.SHFE.TICK.0")
 
     ret2 = api.Unsubscribe("rb2005.SHFE.TICK.0")
 
